{
const TOOLS_RUNNER_URL = "https://functions.yandexcloud.net/d4esian9gs7m7m80qk1q";
const SHOWDOWN_URL = "https://storage.yandexcloud.net/collabza/showdown.min.js";
const TOOL_ID = "3b6660d2-a268-447b-9290-d1488af2f73f";
const BLOCK_ID = "#rec1063088386";

function insertSlideAfter(template_slide, slides_count, slide_index, image) {
  const slide_index_prev = (slide_index + slides_count - 1) % slides_count;
  const slide = template_slide.clone();
  slide.attr("data-slide-index", slide_index);
  slide.find("meta").attr("content", image);
  const zoomable = slide.find('.t-slds__imgwrapper[data-zoomable="yes"]');
  zoomable.attr("bgimgfield", "gi_img__" + slide_index_prev);
  zoomable.attr("data-zoom-target", slide_index_prev);
  zoomable.attr("data-img-zoom-url", image);
  const bgimg = slide.find(".t-slds__imgwrapper .t-bgimg");
  bgimg.attr("data-original", image);
  bgimg.css(
    "background",
    'url("' + image + '") center center / cover no-repeat'
  );
  slide.insertAfter(template_slide);
  return slide;
}

function insertThumbAfter(template_thumb, thumb_index, image) {
  const thumb = template_thumb.clone();
  thumb.attr("data-slide-bullet-for", thumb_index);
  const bgimg = thumb.find(".t-bgimg");
  bgimg.attr("data-original", image);
  bgimg.css(
    "background",
    'url("' + image + '") center center / cover no-repeat'
  );
  thumb.insertAfter(template_thumb);
  return thumb;
}

function translateLoadMore(lang) {
  const translations = {
    EN: "Load more",
    RU: "Загрузить ещё",
    FR: "Charger plus",
    DE: "Mehr laden",
    ES: "Carga más",
    PT: "Carregue mais",
    UK: "Завантажити ще",
    JA: "もっと読み込む",
    ZH: "裝載更多",
  };
  if (lang && translations[lang]) {
    return translations[lang];
  } else {
    return translations.EN;
  }
}

function calculateItemsPerRow(item_template) {
  if (item_template.hasClass("t-col_6")) {
    return 2;
  } else if (item_template.hasClass("t-col_4")) {
    return 3;
  } else if (item_template.hasClass("t-col_3")) {
    return 4;
  }
  return 1;
}

$(document).ready(function () {
  const tool_id = TOOL_ID;
  const block_id = BLOCK_ID.substring(4);
  const block_template = $(BLOCK_ID).removeClass("r_hidden");
  block_template.find("script").remove();

  block_template
    .wrap(`<div id="collabza_rec${block_id}" class="r"></div>`)
    .remove();
  block_template.removeClass("r");
  const collabza_wrapper = $("#collabza_rec" + block_id);

  const item_template = block_template.find(".t778__col:first");
  item_template.find(".t-descr").css("white-space", "pre-wrap");
  const items_per_row = calculateItemsPerRow(item_template);
  const separator_template = $(
    '<div class="t-clear t778__separator t778__separator_number"></div>'
  );
  block_template.find(".t778__container").first().empty();

  const popup_template = block_template.find(".t778__product-full:first");
  block_template.find(".t-popup__container").empty();

  if (!block_template.find(".t778__showmore").length) {
    block_template
      .find(".t778")
      .append(
        $(
          '<div class="t778__buttonwrapper"><div class="t778__showmore t-btn t-btn_sm"><table style="width:100%; height:100%;"><tbody><tr><td></td></tr></tbody></table></div></div>'
        )
      );
  }
  block_template.find(".t778__showmore").find("td").text("...");

  let show_count = parseInt(
    block_template.find(".t778").attr("data-show-count")
  );
  if (!show_count || show_count > 100) {
    show_count = 100;
  }

  const project_id = $("#allrecords").attr("data-tilda-project-id");
  const profile = JSON.parse(
    localStorage.getItem(`tilda_members_profile${project_id}`) ||
      localStorage.getItem("memberarea_profile") ||
      "{}"
  );
  profile["login"] = encodeURIComponent(profile["login"]);
  ["groups", "courses"].forEach((key) => delete profile[key]);

  let block;
  let filters;
  let loaded_count;
  let shown_count;

  function initShowMore(offset) {
    const t778 = block.find(".t778");
    let show_more = t778.find(".t778__showmore");
    show_more.replaceWith(show_more.clone());
    show_more = t778.find(".t778__showmore");
    show_more.find("td").text(translateLoadMore(window.tildaBrowserLang));

    shown_count += show_count;
    if (shown_count >= loaded_count && !offset) {
      show_more.hide();
    } else {
      show_more.show();
    }

    t778.find(".t778__col:lt(" + shown_count + ")").show();
    t778.find(".t778__col:gt(" + (shown_count - 1) + ")").hide();
    try {
      // Версия с jQuery
      t778__showSeparator(t778, shown_count - 1);
    } catch (e) {}
    try {
      // Версия без jQuery
      t778__showSeparator(t778[0], shown_count - 1);
    } catch (e) {}

    show_more.off();
    show_more.click(function () {
      shown_count += show_count;
      if (shown_count >= loaded_count && !offset) {
        show_more.hide();
      }
      t778.find(".t778__col:lt(" + shown_count + ")").show();
      try {
        // Версия с jQuery
        t778__showSeparator(t778, shown_count - 1);
      } catch (e) {}
      try {
        // Версия без jQuery
        t778__showSeparator(t778[0], shown_count - 1);
      } catch (e) {}

      if (shown_count > loaded_count && offset) {
        shown_count -= show_count;
        show_more.off();
        show_more.find("td").text("...");
        loadMore({ data: { offset: offset } });
      }
      $(window).trigger("resize");
      window.dispatchEvent(new Event("resize"));
    });
  }

  function loadMore(event) {
    $.post(
      TOOLS_RUNNER_URL,
      JSON.stringify({
        tool_id: tool_id,
        profile: profile,
        project_id: project_id,
        referer: document.location.origin,
        user_agent: navigator.userAgent,
        filters: filters,
        offset: event.data.offset,
      }),
      function (data) {
        const converter = new showdown.Converter();
        function setConverted(element, value) {
          element.html(converter.makeHtml(String(value)));
          element.css("white-space", "pre-wrap");
          element.find("blockquote").css({
            "white-space": "normal",
            "border-left": "3px solid #333333",
            "padding-left": "20px",
          });
          element.find("img").css("width", "100%");
        }

        const item_container = block.find(".t778__container").first();
        const popup_container = block.find(".t-popup__container");
        data.records?.forEach((record, index, records) => {
          item = item_template.clone();
          popup = popup_template.clone();
          item.attr("data-product-lid", record.id);
          item.attr("data-product-url", record.product_url || "");
          popup.attr("data-product-lid", record.id);
          popup.attr("data-product-url", record.product_url || "");
          popup.attr("id", "t778__product-" + record.id);

          if ("title" in record) {
            setConverted(item.find(".t778__title"), record.title);
            setConverted(popup.find(".t778__title"), record.title);
          }
          if ("card_description" in record) {
            setConverted(item.find(".t778__descr"), record.card_description);
          }
          if ("popup_text" in record) {
            setConverted(popup.find(".t778__descr"), record.popup_text);
          }
          if ("image_list" in record) {
            const image_list = record.image_list;
            item.find(".t778__bgimg, .t778__img").each(function (i) {
              if (image_list[i]) {
                $(this).attr("data-original", image_list[i]);
                if ($(this).hasClass("t778__bgimg")) {
                  $(this).css(
                    "background",
                    'url("' +
                      image_list[i] +
                      '") center center / cover no-repeat'
                  );
                } else {
                  $(this).attr("src", image_list[i]);
                }
              } else {
                $(this).remove();
              }
            });
            const item_images_count = item.find(
              ".t778__bgimg, .t778__img"
            ).length;
            if (item_images_count === 1) {
              item
                .find(".t778__bgimg_first_hover")
                .removeClass("t778__bgimg_first_hover");
              item
                .find(".t778__img_first_hover")
                .removeClass("t778__img_first_hover");
            } else if (item_images_count === 0) {
              item.find(".t778__imgwrapper").remove();
            }

            popup_slides = popup.find(".t-slds__item");
            popup_thumbs = popup.find(".t-slds__thumbsbullet");
            if (image_list.length > 0) {
              let last_slide = popup_slides.first();
              let last_thumb = popup_thumbs.first();
              record.image_list.forEach((image, index) => {
                last_slide = insertSlideAfter(
                  last_slide,
                  image_list.length,
                  index + 1,
                  image
                );
                last_thumb = insertThumbAfter(last_thumb, index + 1, image);
              });
              if (image_list.length === 1) {
                popup.find(".t-slds__arrow").remove();
                popup.find(".t-slds__thumbsbullet-wrapper").remove();
              }
            }
            popup_slides.remove();
            popup_thumbs.remove();
          }
          if ("price" in record) {
            if (record.price) {
              item.find(".t778__price .t778__price-value").text(record.price);
              popup.find(".t778__price .t778__price-value").text(record.price);
            } else {
              item.find(".t778__price-wrapper").remove();
              popup.find(".t778__price-wrapper").remove();
            }
          }
          if ("price_old" in record) {
            if (record.price_old) {
              item
                .find(".t778__price_old .t778__price-value")
                .text(record.price_old);
              popup
                .find(".t778__price_old .t778__price-value")
                .text(record.price_old);
            } else {
              item.find(".t778__price_old").remove();
              popup.find(".t778__price_old").remove();
            }
          }
          const button1 = item.find(".t778__btn:not(.t778__btn_second)");
          const button2 = item.find(".t778__btn_second");
          const popup_button = popup.find(".t778__btn");
          if ("button_title" in record) {
            if (record.button_title) {
              button1.find("td").text(record.button_title);
            } else {
              button1.remove();
            }
          }
          if ("button_link_prod" in record) {
            if (record.button_link_prod) {
              button1.attr("href", record.button_link_prod);
              item
                .find(".t778__imgwrapper")
                .parent("a")
                .attr("href", record.button_link_prod);
              item
                .find(".t778__textwrapper")
                .parent("a")
                .attr("href", record.button_link_prod);
            } else {
              button1.remove();
              item.find(".t778__imgwrapper").parent("a").removeAttr("href");
              item.find(".t778__textwrapper").parent("a").removeAttr("href");
            }
          }
          if ("button2_title" in record) {
            if (record.button2_title) {
              button2.find("td").text(record.button2_title);
              popup_button.find("td").text(record.button2_title);
            } else {
              button2.remove();
              popup_button.remove();
            }
          }
          if ("button2_link_prod" in record) {
            if (record.button2_link_prod) {
              button2.attr("href", record.button2_link_prod);
              popup_button.attr("href", record.button2_link_prod);
            } else {
              button2.remove();
              popup_button.remove();
            }
          }
          if ("card_mark" in record) {
            if (record.card_mark) {
              item.find(".t778__mark").text(record.card_mark);
            } else {
              item.find(".t778__mark").remove();
            }
          }
          if ("subtitle_prod" in record) {
            item.find(".js-product-sku").text(record.subtitle_prod);
            popup.find(".js-product-sku").text(record.subtitle_prod);
          }
          for (let i = 3; i >= 1; i--) {
            if (`option${i}_variants` in record) {
              if (record[`option${i}_variants`].length) {
                const variants = popup
                  .find(".t-product__option-select")
                  .eq(i - 1)
                  .empty();
                for (const variant of record[`option${i}_variants`]) {
                  const params = variant.split("=");
                  variants.append(
                    `<option value="${params[0]}" data-product-variant-price="${
                      params[1] || ""
                    }">${params[0]}</option>`
                  );
                }
                variants.val(variants.find("option:first").val());
              } else {
                popup
                  .find(".t-product__option")
                  .eq(i - 1)
                  .remove();
              }
            }
          }

          item_container.append(item);
          loaded_count += 1;
          if (
            loaded_count % items_per_row === 0 &&
            (index < records.length - 1 || data.offset)
          ) {
            item_container.append(
              separator_template
                .clone()
                .attr("data-product-separator-number", loaded_count)
            );
          }
          popup_container.append(popup);
        });

        t778__init(block_id);
        initShowMore(data.offset);

        $(".t-zoomer__wrapper").remove();
        if (typeof t_initZoom === "function") {
          t_initZoom();
        }

        if (loaded_count === 0) {
          item_container.append(
            '<div class="t778__col t-col t-col_12 t-align_center t-name_xl no_records"></div>'
          );
        }
        $(window).trigger("resize");
        window.dispatchEvent(new Event("resize"));
        if (typeof t_animate__startAnimation === "function") {
          t_animate__startAnimation();
        }
        try {
          twishlist__addProductButtons();
        } catch (e) {}
        block.trigger("collabza_loaded");
      }
    ).fail(function (data) {
      block.text(
        `Collabza error (${BLOCK_ID}): ${data?.responseJSON?.message}`
      );
      block.css("text-align", "center").show();
    });
  }

  collabza_wrapper.on("collabza_init", function () {
    block = block_template.clone();
    block.append(
      '<style>.no_records:after { content: "¯\\\\\\\\_(ツ)_/¯"}</style>'
    );
    ["t395__off", "t397__off"].forEach((off_class) => {
      if ($("BLOCK_ID").length && !$("BLOCK_ID").hasClass(off_class)) {
        block.removeClass(off_class);
      }
    });
    collabza_wrapper.empty().append(block);
    filters = new URLSearchParams(window.location.search).get(
      `filters${block_id}`
    );
    loaded_count = 0;
    shown_count = 0;
    $.getScript(SHOWDOWN_URL, function () {
      loadMore({ data: { offset: null } });
    });
  });
  collabza_wrapper.trigger("collabza_init");
});
}
